### Commencer

PDFMathTranslate est un puissant outil de traduction de PDF. Vous pouvez installer et commencer à utiliser cet outil de différentes manières.

---

### Installation

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Recommandé pour Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Recommandé pour Linux</small>
3. [**uv** (un gestionnaire de paquets Python)](./INSTALLATION_uv.md) <small>Recommandé pour macOS</small>

---

### Utilisation

1. [Utilisation de **WebUI**](./USAGE_webui.md)
2. [Utilisation du **Plugin Zotero**](https://github.com/guaguastandup/zotero-pdf2zh) (Programme tiers)
3. [Utilisation de la **Ligne de commande**](./USAGE_commandline.md)

<div align="right"> 
<h6><small>Une partie du contenu de cette page a été traduite par GPT et peut contenir des erreurs.</small></h6>